# SPDX-License-Identifier: Apache-2.0

import numpy as np


def abs(input: np.ndarray) -> np.ndarray:
    return np.abs(input)
